@@ -1,14 +1,17 @@
 """Test of expression comparison."""
 
-from ufl import Coefficient, Cofunction, FiniteElement, FunctionSpace, Mesh, VectorElement, triangle
+from ufl import Coefficient, Cofunction, FunctionSpace, Mesh, triangle
+from ufl.finiteelement import FiniteElement
+from ufl.pullback import identity_pullback
+from ufl.sobolevspace import H1
 
 
 def test_comparison_of_coefficients():
-    V = FiniteElement("CG", triangle, 1)
-    U = FiniteElement("CG", triangle, 2)
-    Ub = FiniteElement("CG", triangle, 2)
+    V = FiniteElement("Lagrange", triangle, 1, (), identity_pullback, H1)
+    U = FiniteElement("Lagrange", triangle, 2, (), identity_pullback, H1)
+    Ub = FiniteElement("Lagrange", triangle, 2, (), identity_pullback, H1)
 
-    domain = Mesh(VectorElement("Lagrange", triangle, 1))
+    domain = Mesh(FiniteElement("Lagrange", triangle, 1, (2,), identity_pullback, H1))
     v_space = FunctionSpace(domain, V)
     u_space = FunctionSpace(domain, U)
     ub_space = FunctionSpace(domain, Ub)
@@ -36,11 +39,11 @@ def test_comparison_of_coefficients():
 
 
 def test_comparison_of_cofunctions():
-    V = FiniteElement("CG", triangle, 1)
-    U = FiniteElement("CG", triangle, 2)
-    Ub = FiniteElement("CG", triangle, 2)
+    V = FiniteElement("Lagrange", triangle, 1, (), identity_pullback, H1)
+    U = FiniteElement("Lagrange", triangle, 2, (), identity_pullback, H1)
+    Ub = FiniteElement("Lagrange", triangle, 2, (), identity_pullback, H1)
 
-    domain = Mesh(VectorElement("Lagrange", triangle, 1))
+    domain = Mesh(FiniteElement("Lagrange", triangle, 1, (2,), identity_pullback, H1))
     v_space = FunctionSpace(domain, V)
     u_space = FunctionSpace(domain, U)
     ub_space = FunctionSpace(domain, Ub)
@@ -68,8 +71,8 @@ def test_comparison_of_cofunctions():
 
 
 def test_comparison_of_products():
-    V = FiniteElement("CG", triangle, 1)
-    domain = Mesh(VectorElement("Lagrange", triangle, 1))
+    V = FiniteElement("Lagrange", triangle, 1, (), identity_pullback, H1)
+    domain = Mesh(FiniteElement("Lagrange", triangle, 1, (2,), identity_pullback, H1))
     v_space = FunctionSpace(domain, V)
     v = Coefficient(v_space)
     u = Coefficient(v_space)
@@ -82,8 +85,8 @@ def test_comparison_of_products():
 
 
 def test_comparison_of_sums():
-    V = FiniteElement("CG", triangle, 1)
-    domain = Mesh(VectorElement("Lagrange", triangle, 1))
+    V = FiniteElement("Lagrange", triangle, 1, (), identity_pullback, H1)
+    domain = Mesh(FiniteElement("Lagrange", triangle, 1, (2,), identity_pullback, H1))
     v_space = FunctionSpace(domain, V)
     v = Coefficient(v_space)
     u = Coefficient(v_space)
@@ -96,8 +99,8 @@ def test_comparison_of_sums():
 
 
 def test_comparison_of_deeply_nested_expression():
-    V = FiniteElement("CG", triangle, 1)
-    domain = Mesh(VectorElement("Lagrange", triangle, 1))
+    V = FiniteElement("Lagrange", triangle, 1, (), identity_pullback, H1)
+    domain = Mesh(FiniteElement("Lagrange", triangle, 1, (2,), identity_pullback, H1))
     v_space = FunctionSpace(domain, V)
     v = Coefficient(v_space, count=1)
     u = Coefficient(v_space, count=1)
@@ -110,8 +113,9 @@ def test_comparison_of_deeply_nested_expression():
             elif i % 3 == 1:
                 a = a * i
             elif i % 3 == 2:
-                a = a ** i
+                a = a**i
         return a
+
     a = build_expr(u)
     b = build_expr(v)
     c = build_expr(w)
