@@ -1,4 +1,4 @@
-"""Basic algorithms for applying functions to subexpressions."""
+"""Basic algorithms for applying functions to sub-expressions."""
 
 # Copyright (C) 2008-2016 Martin Sandve Alnæs
 #
@@ -10,22 +10,28 @@
 # as part of a careful refactoring process, and this file depends on ufl.form
 # which drags in a lot of stuff.
 
-from ufl.core.expr import Expr
-from ufl.corealg.map_dag import map_expr_dag
-from ufl.integral import Integral
-from ufl.form import Form, BaseForm, FormSum, ZeroBaseForm
 from ufl.action import Action
 from ufl.adjoint import Adjoint
 from ufl.constantvalue import Zero
+from ufl.core.expr import Expr
+from ufl.corealg.map_dag import map_expr_dag
+from ufl.form import BaseForm, Form, FormSum, ZeroBaseForm
+from ufl.integral import Integral
 
 
 def map_integrands(function, form, only_integral_type=None):
-    """Apply transform(expression) to each integrand expression in form, or to form if it is an Expr."""
+    """Map integrands.
+
+    Apply transform(expression) to each integrand expression in form, or
+    to form if it is an Expr.
+    """
     if isinstance(form, Form):
-        mapped_integrals = [map_integrands(function, itg, only_integral_type)
-                            for itg in form.integrals()]
-        nonzero_integrals = [itg for itg in mapped_integrals
-                             if not isinstance(itg.integrand(), Zero)]
+        mapped_integrals = [
+            map_integrands(function, itg, only_integral_type) for itg in form.integrals()
+        ]
+        nonzero_integrals = [
+            itg for itg in mapped_integrals if not isinstance(itg.integrand(), Zero)
+        ]
         return Form(nonzero_integrals)
     elif isinstance(form, Integral):
         itg = form
@@ -34,11 +40,16 @@ def map_integrands(function, form, only_integral_type=None):
         else:
             return itg
     elif isinstance(form, FormSum):
-        mapped_components = [map_integrands(function, component, only_integral_type)
-                             for component in form.components()]
-        nonzero_components = [(component, w) for component, w in zip(mapped_components, form.weights())
-                              # Catch ufl.Zero and ZeroBaseForm
-                              if component != 0]
+        mapped_components = [
+            map_integrands(function, component, only_integral_type)
+            for component in form.components()
+        ]
+        nonzero_components = [
+            (component, w)
+            for component, w in zip(mapped_components, form.weights())
+            # Catch ufl.Zero and ZeroBaseForm
+            if component != 0
+        ]
 
         # Simplify case with one nonzero component and the corresponding weight is 1
         if len(nonzero_components) == 1 and nonzero_components[0][1] == 1:
@@ -59,7 +70,9 @@ def map_integrands(function, form, only_integral_type=None):
         # Zeros are caught inside `Action.__new__`
         return Action(left, right)
     elif isinstance(form, ZeroBaseForm):
-        arguments = tuple(map_integrands(function, arg, only_integral_type) for arg in form._arguments)
+        arguments = tuple(
+            map_integrands(function, arg, only_integral_type) for arg in form._arguments
+        )
         return ZeroBaseForm(arguments)
     elif isinstance(form, (Expr, BaseForm)):
         integrand = form
@@ -70,5 +83,6 @@ def map_integrands(function, form, only_integral_type=None):
 
 def map_integrand_dags(function, form, only_integral_type=None, compress=True):
     """Map integrand dags."""
-    return map_integrands(lambda expr: map_expr_dag(function, expr, compress),
-                          form, only_integral_type)
+    return map_integrands(
+        lambda expr: map_expr_dag(function, expr, compress), form, only_integral_type
+    )
