@@ -8,11 +8,13 @@
 #
 # Modified by Anders Logg, 2009-2010
 
-from ufl.classes import CoefficientDerivative, Interpolate, ExternalOperator, Form
-from ufl.constantvalue import as_ufl
-from ufl.corealg.multifunction import MultiFunction
-from ufl.algorithms.map_integrands import map_integrand_dags
 from ufl.algorithms.analysis import has_exact_type
+from ufl.algorithms.map_integrands import map_integrand_dags
+from ufl.classes import CoefficientDerivative, Form
+from ufl.constantvalue import as_ufl
+from ufl.core.external_operator import ExternalOperator
+from ufl.core.interpolate import Interpolate
+from ufl.corealg.multifunction import MultiFunction
 
 
 class Replacer(MultiFunction):
@@ -31,7 +33,9 @@ class Replacer(MultiFunction):
             return x.ufl_shape
 
         if not all(get_shape(k) == get_shape(v) for k, v in mapping.items()):
-            raise ValueError("Replacement expressions must have the same shape as what they replace.")
+            raise ValueError(
+                "Replacement expressions must have the same shape as what they replace."
+            )
 
     def ufl_type(self, o, *args):
         """Replace a ufl_type."""
@@ -86,6 +90,7 @@ def replace(e, mapping):
     if has_exact_type(e, CoefficientDerivative):
         # Hack to avoid circular dependencies
         from ufl.algorithms.ad import expand_derivatives
+
         e = expand_derivatives(e)
 
     return map_integrand_dags(Replacer(mapping2), e)
