@@ -10,19 +10,15 @@
 # Modified by Massimiliano Leoni, 2016.
 # Modified by Cecile Daversin-Catty, 2018.
 # Modified by Ignacia Fierro-Piccardo 2023.
-import warnings
 
-from ufl.core.ufl_type import ufl_type
-from ufl.core.terminal import FormArgument
 from ufl.argument import Argument
-from ufl.finiteelement import FiniteElementBase
-from ufl.domain import default_domain
-from ufl.functionspace import AbstractFunctionSpace, FunctionSpace, MixedFunctionSpace
+from ufl.core.terminal import FormArgument
+from ufl.core.ufl_type import ufl_type
+from ufl.duals import is_dual, is_primal
 from ufl.form import BaseForm
+from ufl.functionspace import AbstractFunctionSpace, MixedFunctionSpace
 from ufl.split_functions import split
 from ufl.utils.counted import Counted
-from ufl.duals import is_primal, is_dual
-
 
 # --- The Coefficient class represents a coefficient in a form ---
 
@@ -45,22 +41,13 @@ class BaseCoefficient(Counted):
         """Initalise."""
         Counted.__init__(self, count, Coefficient)
 
-        if isinstance(function_space, FiniteElementBase):
-            # For legacy support for .ufl files using cells, we map
-            # the cell to The Default Mesh
-            element = function_space
-            domain = default_domain(element.cell())
-            function_space = FunctionSpace(domain, element)
-            warnings.warn("The use of FiniteElement as an input to Coefficient will be deprecated by December 2023. "
-                          "Please, use FunctionSpace instead", FutureWarning)
-        elif not isinstance(function_space, AbstractFunctionSpace):
-            raise ValueError("Expecting a FunctionSpace or FiniteElement.")
+        if not isinstance(function_space, AbstractFunctionSpace):
+            raise ValueError("Expecting a FunctionSpace.")
 
         self._ufl_function_space = function_space
-        self._ufl_shape = function_space.ufl_element().value_shape()
+        self._ufl_shape = function_space.value_shape
 
-        self._repr = "BaseCoefficient(%s, %s)" % (
-            repr(self._ufl_function_space), repr(self._count))
+        self._repr = "BaseCoefficient(%s, %s)" % (repr(self._ufl_function_space), repr(self._count))
 
     @property
     def ufl_shape(self):
@@ -88,7 +75,11 @@ class BaseCoefficient(Counted):
         return self._ufl_function_space.ufl_domains()
 
     def _ufl_signature_data_(self, renumbering):
-        """Signature data for form arguments depend on the global numbering of the form arguments and domains."""
+        """Signature data.
+
+        Signature data for form arguments depend on the global numbering
+        of the form arguments and domains.
+        """
         count = renumbering[self]
         fsdata = self._ufl_function_space._ufl_signature_data_(renumbering)
         return ("Coefficient", count, fsdata)
@@ -123,16 +114,20 @@ class Cofunction(BaseCoefficient, BaseForm):
         "ufl_operands",
         "_repr",
         "_ufl_shape",
-        "_hash"
+        "_hash",
     )
     _primal = False
     _dual = True
 
+    __eq__ = BaseForm.__eq__
+
     def __new__(cls, *args, **kw):
         """Create a new Cofunction."""
         if args[0] and is_primal(args[0]):
-            raise ValueError("ufl.Cofunction takes in a dual space. If you want to define a coefficient "
-                             "in the primal space you should use ufl.Coefficient.")
+            raise ValueError(
+                "ufl.Cofunction takes in a dual space. If you want to define a coefficient "
+                "in the primal space you should use ufl.Coefficient."
+            )
         return super().__new__(cls)
 
     def __init__(self, function_space, count=None):
@@ -142,8 +137,7 @@ class Cofunction(BaseCoefficient, BaseForm):
 
         self.ufl_operands = ()
         self._hash = None
-        self._repr = "Cofunction(%s, %s)" % (
-            repr(self._ufl_function_space), repr(self._count))
+        self._repr = "Cofunction(%s, %s)" % (repr(self._ufl_function_space), repr(self._count))
 
     def equals(self, other):
         """Check equality."""
@@ -155,9 +149,7 @@ class Cofunction(BaseCoefficient, BaseForm):
 
     def __hash__(self):
         """Hash."""
-        return hash(("Cofunction",
-                     hash(self._ufl_function_space),
-                     self._count))
+        return hash(("Cofunction", hash(self._ufl_function_space), self._count))
 
     def _analyze_form_arguments(self):
         """Analyze which Argument and Coefficient objects can be found in the form."""
@@ -190,8 +182,7 @@ class Coefficient(FormArgument, BaseCoefficient):
         FormArgument.__init__(self)
         BaseCoefficient.__init__(self, function_space, count)
 
-        self._repr = "Coefficient(%s, %s)" % (
-            repr(self._ufl_function_space), repr(self._count))
+        self._repr = "Coefficient(%s, %s)" % (repr(self._ufl_function_space), repr(self._count))
 
     def ufl_domains(self):
         """Get the UFL domains."""
@@ -212,13 +203,16 @@ class Coefficient(FormArgument, BaseCoefficient):
 
 # --- Helper functions for subfunctions on mixed elements ---
 
+
 def Coefficients(function_space):
     """Create a Coefficient in a mixed space.
 
     Returns a tuple with the function components corresponding to the subelements.
     """
     if isinstance(function_space, MixedFunctionSpace):
-        return [Coefficient(fs) if is_primal(fs) else Cofunction(fs)
-                for fs in function_space.num_sub_spaces()]
+        return [
+            Coefficient(fs) if is_primal(fs) else Cofunction(fs)
+            for fs in function_space.num_sub_spaces()
+        ]
     else:
         return split(Coefficient(function_space))
